@@ -204,7 +204,7 @@ test_that("invert = T, and custom suffixes dont result in failed anti_join()", {
 })
 
 test_that("multiple y tbl_intervals can be passed to bed_intersect (#220)", {
-  x <- trbl_interval(
+  x <- tibble::tribble(
     ~ chrom, ~ start, ~ end,
     "chr1", 100, 500,
     "chr2", 200, 400,
@@ -212,7 +212,7 @@ test_that("multiple y tbl_intervals can be passed to bed_intersect (#220)", {
     "chr2", 800, 900
   )
 
-  y <- trbl_interval(
+  y <- tibble::tribble(
     ~ chrom, ~ start, ~ end, ~ value,
     "chr1", 150, 400, 100,
     "chr1", 500, 550, 100,
@@ -220,7 +220,7 @@ test_that("multiple y tbl_intervals can be passed to bed_intersect (#220)", {
     "chr2", 350, 430, 300
   )
 
-  z <- trbl_interval(
+  z <- tibble::tribble(
     ~ chrom, ~ start, ~ end, ~ value,
     "chr1", 150, 400, 100,
     "chr1", 500, 550, 100,
@@ -269,7 +269,7 @@ test_that("groups are respected when passing multiple y tbl_intervals ", {
 })
 
 test_that("same intervals are reported with single and multiple intersection", {
-  x <- trbl_interval(
+  x <- tibble::tribble(
     ~ chrom, ~ start, ~ end,
     "chr1", 100, 500,
     "chr2", 200, 400,
@@ -277,7 +277,7 @@ test_that("same intervals are reported with single and multiple intersection", {
     "chr2", 800, 900
   )
 
-  y <- trbl_interval(
+  y <- tibble::tribble(
     ~ chrom, ~ start, ~ end, ~ value,
     "chr1", 150, 400, 100,
     "chr1", 500, 550, 100,
@@ -285,7 +285,7 @@ test_that("same intervals are reported with single and multiple intersection", {
     "chr2", 350, 430, 300
   )
 
-  z <- trbl_interval(
+  z <- tibble::tribble(
     ~ chrom, ~ start, ~ end, ~ value,
     "chr1", 150, 400, 100,
     "chr1", 500, 550, 100,
@@ -303,7 +303,7 @@ test_that("same intervals are reported with single and multiple intersection", {
 })
 
 test_that("unmatched groups are included when invert = TRUE", {
-  x <- trbl_interval(
+  x <- tibble::tribble(
     ~ chrom, ~ start, ~ end, ~ group,
     "chr1", 100, 500, "A",
     "chr2", 200, 400, "B", # unmatched
@@ -311,7 +311,7 @@ test_that("unmatched groups are included when invert = TRUE", {
     "chr2", 800, 900, "A"
   ) %>% group_by(chrom, group)
 
-  y <- trbl_interval(
+  y <- tibble::tribble(
     ~ chrom, ~ start, ~ end, ~ group,
     "chr1", 150, 400, "A",
     "chr1", 500, 550, "A",
@@ -319,24 +319,24 @@ test_that("unmatched groups are included when invert = TRUE", {
     "chr2", 350, 430, "A"
   ) %>% group_by(chrom, group)
 
-  pred <- trbl_interval(
+  pred <- tibble::tribble(
     ~ chrom, ~ start, ~ end, ~ group,
     "chr2", 200, 400, "B", # unmatched
     "chr2", 800, 900, "A"
   )
 
   res <- bed_intersect(x, y, invert = TRUE)
-  expect_equal(res, pred)
+  expect_equivalent(res, pred)
 })
 
 # from https://github.com/arq5x/bedtools2/blob/master/test/intersect/test-intersect.sh
 test_that("0 length records", {
-  x <- trbl_interval(
+  x <- tibble::tribble(
     ~ chrom, ~ start, ~ end,
     "chr7", 33059403, 33059403
   )
 
-  y <- trbl_interval(
+  y <- tibble::tribble(
     ~ chrom, ~ start, ~ end, ~ group, ~ type,
     "chr7", 32599076, 33069221, "NAq", "intron",
     "chr7", 33059336L, 33060883L, "NT5C3A", "intron"
